@@ -1,4 +1,4 @@
-from Camera import Camera
+from GhostScan.Camera import Camera
 
 from abc import ABC
 
